@@ -1,13 +1,11 @@
 /* Document.m
  * Cenon document class
  *
- * Copyright (C) 1996-2010 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author: Georg Fleischmann
  *
  * Created:  1996-02-09
- * Modified: 2010-06-30 (-saveTiff added)
- *           2008-10-21 (clean-up)
- *           2008-07-24 (document units, update units)
+ * Modified: 2005-09-01 (printing of multi page documents added)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -46,18 +44,15 @@
 #include "HPGLExportSub.h"
 #include "GerberExportSub.h"
 #include "DXFExportSub.h"
-#ifdef __APPLE__
-#    include "GSPropertyListSerialization.h"
-#endif
 
-#define XOFFSET             5.0     // Offset of subsequent windows
-#define YOFFSET             -20.0
-#define	MAXWINWIDTH         900     // maximum size of the window
-#define	MAXWINHEIGHT        750
+#define XOFFSET		5.0 	// Offset of subsequent windows
+#define YOFFSET 	-20.0
+#define	MAXWINWIDTH	900	// maximum size of the window
+#define	MAXWINHEIGHT	750
 
-#define DOCUMENT_VERSION    102
-#define DOCUMENT_NAME       @"document"
-#define OUTPUT_NAME         @"output"
+#define DOCUMENT_VERSION	102
+#define DOCUMENT_NAME		@"document"
+#define OUTPUT_NAME		@"output"
 
 /* Private methods */
 @interface Document(PrivateMethods)
@@ -65,7 +60,6 @@
 - (void)initializePrintInfo;
 - (BOOL)setWindowSize:(NSSize)size;
 - (BOOL)loadOutputListsFromFile:(const char*)fileName;
-- (BOOL)saveTiff:(NSString*)filename;
 - (BOOL)saveEPS:(NSString*)filename;
 - (BOOL)saveGerber:(NSString*)filename;
 - (BOOL)saveHPGL:(NSString*)filename;
@@ -163,27 +157,24 @@ static NSMutableArray *zoneList = nil;
  * inches.
  */
 + new
-{   Document	*newDocument = nil;
-
-    newDocument = [[super allocWithZone:[self newZone]] init];
-    //newDocument = [[Document allocWithZone:[Document newZone]] init];
-    if (![NSBundle loadModelNamed:@"Document" owner:newDocument])
+{
+    self = [[super allocWithZone:[self newZone]] init];
+    //self = [[Document allocWithZone:[Document newZone]] init];
+    if (![NSBundle loadModelNamed:@"Document" owner:self])
     {	NSLog(@"Cannot load Document model");	
-        [newDocument release];
+        [self release];
         return nil;
     }
 
-    [newDocument setName:nil andDirectory:nil];
-    [newDocument initWindow];
-    return newDocument;
+    [(Document*)self setName:nil andDirectory:nil];
+    [(Document*)self initWindow];
+
+    return self;
 }
 
 - (id)init
 {
     [super init];
-
-    baseUnit = -1;  // use unit from Preferences
-
     //[self registerForServicesMenu];
     return self;
 }
@@ -230,17 +221,17 @@ static NSMutableArray *zoneList = nil;
     return self;
 }
 
-/* modified: 2008-07-24 (load baseUnit, project settings)
+/* modified: 2002-11-29
  */
 + newFromFile:(NSString*)fileName
-{   Document        *newDocument = nil;
-    NSDictionary    *plist = nil;
-    NSString        *fileDirectory = nil, *outputFile = nil;
-    NSString        *directoryContainingDocument = nil;
-    NSFileManager   *fileManager = [NSFileManager defaultManager];
-    BOOL            isDirectory = NO;
-    DocView         *view;
-    NSRect          fRect;
+{   Document		*newDocument = nil;
+    NSDictionary	*plist = nil;
+    NSString		*fileDirectory = nil, *outputFile = nil;
+    NSString		*directoryContainingDocument = nil;
+    NSFileManager	*fileManager = [NSFileManager defaultManager];
+    BOOL		isDirectory = NO;
+    DocView		*view;
+    NSRect		fRect;
 
     if ([fileManager fileExistsAtPath:fileName isDirectory:&isDirectory])
     {
@@ -275,17 +266,10 @@ static NSMutableArray *zoneList = nil;
             [newDocument->printInfo setHorizontalPagination:NSAutoPagination];
             [newDocument->printInfo setVerticalPagination:NSAutoPagination];
 
-            /* Project Info */
-            newDocument->docVersion   = [[plist objectForKey:@"DocVersion"] retain];
-            newDocument->docAuthor    = [[plist objectForKey:@"Author"]     retain];
-            newDocument->docCopyright = [[plist objectForKey:@"Copyright"]  retain];
-            newDocument->docComment   = [[plist objectForKey:@"Comment"]    retain];
-
-            /* Project Settings */
-            if ([plist objectForKey:@"DocSettings"])
-                newDocument->docSettingsDict = [[plist objectForKey:@"DocSettings"] mutableCopy];
-            if ([plist objectForKey:@"Unit"])
-                newDocument->baseUnit        = [plist intForKey:@"Unit"];
+            newDocument->docVersion = [[plist objectForKey:@"DocVersion"] retain];
+            newDocument->docAuthor = [[plist objectForKey:@"Author"] retain];
+            newDocument->docCopyright = [[plist objectForKey:@"Copyright"] retain];
+            newDocument->docComment = [[plist objectForKey:@"Comment"] retain];
 
             directoryContainingDocument = fileDirectory ? fileDirectory
                                                         : [fileName stringByDeletingLastPathComponent];
@@ -307,18 +291,6 @@ static NSMutableArray *zoneList = nil;
             }
 
             [newDocument->window setFrameFromString:[plist objectForKey:@"WindowFrame"]];
-#ifdef __APPLE__    // needed, if a folded window is loaded to restore the window frame
-            {   float  h = [plist floatForKey:@"WindowUnfoldedHeight"];
-
-                [newDocument->window setUnfoldedHeight:h];
-                if ( h > 20.0 ) // folded window: we have to reinforce the frame height
-                {   NSRect  frame = rectFromPropertyList([plist objectForKey:@"WindowFrame"]);
-
-                    //frame.size.height = h;    // if we want to open windows unfolded (add y!)
-                    [newDocument->window setFrame:frame display:NO];
-                }
-            }
-#endif
             /* GNUSTEP: make sure window is not bigger than necessary
              *          (the window frame doesn't include title bar and resize bar)
              */
@@ -344,12 +316,12 @@ static NSMutableArray *zoneList = nil;
 
             [view setDocument:newDocument];
             newDocument->magazineIndex = [plist intForKey:@"MagazineIndex"];
+            [[NSNotificationCenter defaultCenter] postNotificationName:DocWindowDidChange
+                                                                object:newDocument];
             [newDocument->scrollView setDocumentView:view];
             [view release];
             [newDocument->scrollView setDocument:newDocument];
             [newDocument setName:fileDirectory ? fileDirectory : fileName];	// needed to load VImage
-            [[NSNotificationCenter defaultCenter] postNotificationName:DocWindowDidChange
-                                                                object:newDocument];    // moved from before -setDocumentView: to here
             [newDocument->window setDocument:newDocument];
             [newDocument->window makeFirstResponder:view];
             if ( [[plist objectForKey:@"Data"] isKindOfClass:[NSDictionary class]] )
@@ -372,9 +344,7 @@ static NSMutableArray *zoneList = nil;
                     NS_ENDHANDLER
                 }
                 else
-                {   [view setAllLayerDirty:YES];
-                    [newDocument setDirty:NO];	// only layers are dirty to calculate output, not the document
-                }
+                    [view setAllLayerDirty:YES];
             }
 
             [newDocument resetScrollers];	// ???
@@ -385,8 +355,6 @@ static NSMutableArray *zoneList = nil;
             fRect = rectFromPropertyList([plist objectForKey:@"ViewSize"]);
             [view setFrameSize:fRect.size];
 
-            if ( [plist objectForKey:@"hasCoordBox"] && [plist intForKey:@"hasCoordBox"] == 0 )
-                [newDocument->window enableCoordDisplay:NO];
             [newDocument->window makeKeyAndOrderFront:newDocument];
             [newDocument->window makeFirstResponder:view];	// removed by makeKeyAndOrderFront !
             [newDocument->window setMiniwindowImage:[NSImage imageNamed:@"typeCenon"]];
@@ -445,16 +413,15 @@ static NSMutableArray *zoneList = nil;
 
 /*
  * Creates a new document from what is in the passed stream.
- * modified: 2008-07-19 (-init allocated document)
  */
 + newFromList:(NSMutableArray*)list
-{   NSRect          frameRect, fRect;
-    DocView         *view;
-    TileScrollView  *sView;
-    DocWindow       *win;
-    Document        *newDocument;
+{   NSRect		frameRect, fRect;
+    DocView		*view;
+    TileScrollView	*sView;
+    DocWindow		*win;
+    Document		*newDocument;
 
-    newDocument = [[super allocWithZone:[self newZone]] init];
+    newDocument = [super allocWithZone:[self newZone]];
     if (![NSBundle loadModelNamed:@"Document" owner:newDocument])
     {	NSLog(@"Cannot load Document model");	
         [newDocument release];
@@ -610,9 +577,9 @@ static NSMutableArray *zoneList = nil;
 #endif
 
 - (void)scale:(float)x :(float)y withCenter:(NSPoint)center
-{   NSPoint	p = {0, 0};
+{   NSPoint		p = {0, 0};
     DocView	*view = [scrollView documentView];
-    NSRect	oldFrame = [view frame], bRect;
+    NSRect		oldFrame = [view frame], bRect;
 
     /* scale doc view and cache window */
     [view scaleUnitSquareToSize:NSMakeSize(x, y)];
@@ -736,97 +703,28 @@ static NSMutableArray *zoneList = nil;
     docVersion = [newVersion retain];
     [self setDirty:YES];
 }
-- (NSString*)docVersion     { return docVersion; }
+- (NSString*)docVersion		{ return docVersion; }
 - (void)setDocAuthor:(NSString*)newAuthor
 {
     [docAuthor release];
     docAuthor = [newAuthor retain];
     [self setDirty:YES];
 }
-- (NSString*)docAuthor      { return docAuthor; }
+- (NSString*)docAuthor		{ return docAuthor; }
 - (void)setDocCopyright:(NSString*)newCopyright
 {
     [docCopyright release];
     docCopyright = [newCopyright retain];
     [self setDirty:YES];
 }
-- (NSString*)docCopyright   { return docCopyright; }
+- (NSString*)docCopyright	{ return docCopyright; }
 - (void)setDocComment:(NSString*)newComment
 {
     [docComment release];
     docComment = [newComment copy];
     [self setDirty:YES];
 }
-- (NSString*)docComment     { return docComment; }
-
-/* Document setting
- * created:  2008-07-19
- * modified: 2008-07-24
- */
-- (NSMutableDictionary*)docSettingsDict
-{
-    if (!docSettingsDict)
-        docSettingsDict = [[NSMutableDictionary dictionary] retain];
-    return docSettingsDict;
-}
-- (void)setBaseUnit:(CenonUnit)unit { baseUnit = unit; }
-- (CenonUnit)baseUnitFlat           { return baseUnit; }
-- (CenonUnit)baseUnit
-{   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    return (baseUnit == -1) ? [defaults integerForKey:@"unit"] : baseUnit;
-}
-- (float)convertToUnit:(float)iValue
-{   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    CenonUnit       unit = (baseUnit == -1) ? [defaults integerForKey:@"unit"] : baseUnit;
-
-    switch ( unit )
-    {
-        case UNIT_MM:		return (iValue * 25.4/72.0);
-        case UNIT_INCH:		return (iValue / 72.0);
-        default:
-        case UNIT_POINT:	return iValue;
-    }
-    return iValue;
-}
-- (float)convertFrUnit:(float)uValue
-{   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    CenonUnit       unit = (baseUnit == -1) ? [defaults integerForKey:@"unit"] : baseUnit;
-
-    switch ( unit )
-    {
-        case UNIT_MM:		return (uValue / 25.4*72.0);
-        case UNIT_INCH:		return (uValue * 72.0);
-        default:
-        case UNIT_POINT:	return uValue;
-    }
-    return uValue;
-}
-- (float)convertMMToUnit:(float)mmValue
-{   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    CenonUnit       unit = (baseUnit == -1) ? [defaults integerForKey:@"unit"] : baseUnit;
-
-    switch ( unit )
-    {
-        default:
-        case UNIT_MM:		return mmValue;
-        case UNIT_INCH:		return mmValue / 25.4;
-        case UNIT_POINT:	return mmValue * 72.0/25.4;
-    }
-    return mmValue;
-}
-- (float)convertUnitToMM:(float)uValue
-{   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    CenonUnit       unit = (baseUnit == -1) ? [defaults integerForKey:@"unit"] : baseUnit;
-
-    switch ( unit )
-    {
-        default:
-        case UNIT_MM:		return uValue;
-        case UNIT_INCH:		return uValue * 25.4;
-        case UNIT_POINT:	return uValue / 72.0*25.4;
-    }
-    return uValue;
-}
+- (NSString*)docComment		{ return docComment; }
 
 
 /*
@@ -872,29 +770,29 @@ static NSMutableArray *zoneList = nil;
 
     if ((newName && [newName length]) || !name)
     {
-        if (!newName || ![newName length])
+ 	if (!newName || ![newName length])
         {
-            newName = UNTITLED_STRING;
-            if (untitledCount)
-                newName = [newName stringByAppendingFormat:@"%d", untitledCount];
-            untitledCount++;
-        }
-        if (![newName isEqual:name])
+	    newName = UNTITLED_STRING;
+	    if (untitledCount)
+		newName = [newName stringByAppendingFormat:@"%d", untitledCount];
+	    untitledCount++;
+	}
+	if (![newName isEqual:name])
         {
-            [name autorelease];
-            name = [newName copyWithZone:(NSZone*)[self zone]];
-        }
+	    [name autorelease];
+	    name = [newName copyWithZone:(NSZone*)[self zone]];
+	}
     }
 
     if ((newDirectory && [newDirectory length]) || !directory)
     {
-        if (!newDirectory || ![newDirectory length])
-            newDirectory = [(App*)NSApp currentDirectory];
-        if (![newDirectory isEqual:directory])
+ 	if (!newDirectory || ![newDirectory length])
+	    newDirectory = [(App*)NSApp currentDirectory];
+	if (![newDirectory isEqual:directory])
         {
-            [directory autorelease];
-            directory = [newDirectory copyWithZone:(NSZone*)[self zone]];
-        }
+	    [directory autorelease];
+	    directory = [newDirectory copyWithZone:(NSZone*)[self zone]];
+	}
     }
 
     if (!name)
@@ -906,9 +804,6 @@ static NSMutableArray *zoneList = nil;
     {
         [window setTitleWithRepresentedFilename:fileName];
         [window setMiniwindowTitle:fileName];
-#ifdef __APPLE__    // well, he! the are lazy developers at Apple, the above works two times then never again
-        [window setTitle:name];
-#endif
         NSSetZoneName((NSZone*)[self zone], fileName);
     }
 }
@@ -920,18 +815,19 @@ static NSMutableArray *zoneList = nil;
 - (BOOL)setName:(NSString *)file
 {
     if (file)
-    {	NSString *lastComponent = [file lastPathComponent];
-
-        if (![lastComponent isEqual:@""])
+    {
+    	NSString *lastComponent = [file lastPathComponent];
+	
+	if (![lastComponent isEqual:@""])
         {
-            [self setName:lastComponent andDirectory:[file stringByDeletingLastPathComponent]];
-            return YES;
-        }
+	    [self setName:lastComponent andDirectory:[file stringByDeletingLastPathComponent]];
+	    return YES;
+	}
         else
         {
-            [self setName:file andDirectory:nil];
-            return YES;
-        }
+	    [self setName:file andDirectory:nil];
+	    return YES;
+	}
     }
 
     return NO;
@@ -941,7 +837,7 @@ static NSMutableArray *zoneList = nil;
 {
     [window setTitle:title];
     haveSavedDocument = NO;
-    [self setName:title andDirectory:NSHomeDirectory()];
+    [self setName:title andDirectory:vhfHomeDirectory()]; 
 }
 
 - (void)setFontObject:(Type1Font*)fontObj
@@ -1031,19 +927,17 @@ static NSMutableArray *zoneList = nil;
  * 2. remove backup (fileName.cenon~)
  * 3. move file name (old) file to backup (fileName.cenon -> fileName.cenon~)
  * 4. move temporary file to file name (#fileName.cenon -> fileName.cenon)
- *
- * modified: 2007-07-24 (save baseUnit and project settings)
  */
 - (BOOL)save
-{   BOOL                savedOk = NO;
-    NSString            *filename = [self filename];
-    NSString            *backupFilename = [filename stringByAppendingString:@"~"];
-    //NSString          *tmpFilename = [@"#" stringByAppendingString:filename];
-    NSString            *fileDirectory = nil;
-    NSFileManager       *fileManager = [NSFileManager defaultManager];
-    NSMutableDictionary *fileContents;
-    BOOL                isDirectory = YES;
-    NSAutoreleasePool   *pool;
+{   BOOL		savedOk = NO;
+    NSString		*filename = [self filename];
+    NSString		*backupFilename = [filename stringByAppendingString:@"~"];
+    //NSString		*tmpFilename = [@"#" stringByAppendingString:filename];
+    NSString		*fileDirectory = nil;
+    NSFileManager	*fileManager = [NSFileManager defaultManager];
+    NSMutableDictionary	*fileContents;
+    BOOL		isDirectory = YES;
+    NSAutoreleasePool	*pool;
 
     /* file not writable */
     if ( [fileManager fileExistsAtPath:filename] && ![fileManager isWritableFileAtPath:filename] )
@@ -1073,87 +967,30 @@ static NSMutableArray *zoneList = nil;
             [fileContents setObject:[NSString stringWithFormat:@"%d", DOCUMENT_VERSION] forKey:@"Version"];
             [fileContents setObject:propertyListFromNSPrintInfo(printInfo) forKey:@"PrintInfo"];
             [fileContents setObject:[window stringWithSavedFrame] forKey:@"WindowFrame"];
-#ifdef __APPLE__    // needed, if a folded window is saved, to restore the window frame
-            if ( [window isFolded] )
-                [fileContents setObject:propertyListFromFloat([window unfoldedHeight])
-                                 forKey:@"WindowUnfoldedHeight"];
-#endif
             [fileContents setObject:propertyListFromNSRect([[self documentView] bounds]) forKey:@"ViewSize"];
-            [fileContents setInt:[window hasCoordDisplay] forKey:@"hasCoordBox"];
             [fileContents setInt:magazineIndex forKey:@"MagazineIndex"];
             //[fileContents setObject:propertyListFromInt([VGraphic currentGraphicIdentifier]) forKey:@"GraphicIdentifier"];
             [fileContents setObject:@"Cenon" forKey:@"Creator"];
             [fileContents setObject:[[NSCalendarDate date] descriptionWithCalendarFormat:@"%Y-%m-%d %H:%M"] forKey:@"CreationDate"];
-            /* Project Info */
             if (docVersion)
-                [fileContents setObject:docVersion      forKey:@"DocVersion"];
+                [fileContents setObject:docVersion forKey:@"DocVersion"];
             if (docAuthor)
-                [fileContents setObject:docAuthor       forKey:@"Author"];
+                [fileContents setObject:docAuthor forKey:@"Author"];
             if (docCopyright)
-                [fileContents setObject:docCopyright    forKey:@"Copyright"];
+                [fileContents setObject:docCopyright forKey:@"Copyright"];
             if (docComment)
-                [fileContents setObject:docComment      forKey:@"Comment"];
-            /* Project Settings */
-            if (baseUnit != -1)
-                [fileContents setObject:[NSString stringWithFormat:@"%d", baseUnit] forKey:@"Unit"];
-            if (docSettingsDict)
-                [fileContents setObject:docSettingsDict forKey:@"DocSettings"];
-
+                [fileContents setObject:docComment forKey:@"Comment"];
             if ( DOCUMENT_VERSION >= 101 )
                 [fileContents setObject:[[self documentView] propertyList] forKey:@"Data"];
             else
-            {   archiver = [[[NSArchiver alloc] initForWritingWithMutableData:[NSMutableData data]] autorelease];
+            {
+                archiver = [[[NSArchiver alloc] initForWritingWithMutableData:[NSMutableData data]] autorelease];
                 [[self documentView] encodeWithCoder:archiver];
                 [fileContents setObject:[archiver archiverData] forKey:@"Data"];
             }
 
-#ifdef __APPLE__
-            /* ASCII PropertyList... it just doesn't work on Mac OS X,
-             * so we use the class from the GNUstep project so long
-             */
-            if ( Prefs_OSPropertyList ) // ASCII PropertyList (most human readable + half the size of XML)
-            {
-                if ( [NSPropertyListSerialization propertyList:fileContents
-                                              isValidForFormat:NSPropertyListOpenStepFormat] )
-                {   NSData      *data;
-                    NSString    *error = nil;
-                    //NSDictionary *testplist = [NSDictionary dictionary];  // not even this works!
-
-                    data = [NSPropertyListSerialization dataFromPropertyList:fileContents
-                                                                      format:NSPropertyListOpenStepFormat
-                                                            errorDescription:&error];
-                    if (error)
-                    {   NSLog(error); [error release]; }
-                    savedOk = [data writeToFile:filename atomically:YES];
-
-                    /* Apple stuff doesn't work:
-                    if ([NSPropertyListSerialization propertyList:testplist
-                                                isValidForFormat:NSPropertyListOpenStepFormat])
-                        NSLog(@"valid for ASCII");
-                    if ([NSPropertyListSerialization propertyList:testplist
-                                                 isValidForFormat:NSPropertyListXMLFormat_v1_0])
-                        NSLog(@"valid for XML");
-                    data = [NSPropertyListSerialization dataFromPropertyList:testplist
-                                                                      format:NSPropertyListOpenStepFormat
-                                                            errorDescription:&error];
-                    [data writeToFile:@"/Users/georg/Tempo/test.plist" atomically:YES];*/
-                }
-                else
-                {   NSData      *data;
-                    NSString    *error = nil;
-
-                    data = [GSPropertyListSerialization dataFromPropertyList:fileContents
-                                                                      format:NSPropertyListOpenStepFormat
-                                                            errorDescription:&error];
-                    if (error)
-                    {   NSLog(error); [error release]; }
-                    savedOk = [data writeToFile:filename atomically:YES];
-                }
-            }
-            else	// use native PropertyList format
-#endif
-                /* FIXME: converting dictionary to string needs a lot lot of memory !! */
-                savedOk = [fileContents writeToFile:filename atomically:YES];
+            /* FIXME: converting dictionary to string needs a lot lot of memory !! */
+            savedOk = [fileContents writeToFile:filename atomically:YES];
             haveSavedDocument = savedOk;
 
             if ( fileDirectory && savedOk )
@@ -1227,8 +1064,6 @@ static NSMutableArray *zoneList = nil;
             [self saveDXF:path];
         else if ([[path pathExtension] isEqual:FONT_EXT])
             [self saveFont:path];
-        else if ([[path pathExtension] isEqual:TIFF_EXT])
-            [self saveTiff:path];
     }
 
     return NO;
@@ -1303,183 +1138,19 @@ static NSMutableArray *zoneList = nil;
     return savedOk;
 }
 
-/* created: 2010-06-29
- */
-- (BOOL)saveTiff:(NSString*)filename
-{   NSArray             *layerList = [[self documentView] layerList];
-    NSRect              conRect, rect, bbox = NSZeroRect;
-    NSBitmapImageRep	*bitmapImage;
-    NSImage             *img = nil;
-    NSData              *tdata = nil;
-#ifdef __APPLE__
-    NSGraphicsContext   *gContext;
-    CGContextRef        cgContext=nil;
-#else
-    id                  win = nil, conView = nil;
-#endif
-
-    /* only all visible Layers */
-    {   int	l, cnt = [layerList count];
-
-        for (l=0; l<cnt; l++)
-        {	LayerObject	*layerObject = [layerList objectAtIndex:l];
-
-            if ( [layerObject state] ) // visible
-                bbox = NSUnionRect([[self documentView] boundsOfArray:[layerObject list]], bbox);
-        }
-    }
-
-    conRect.origin.x = conRect.origin.y = 10.0;
-    conRect.size.width = bbox.size.width;
-    conRect.size.height = bbox.size.height;
-
-    rect.origin = NSZeroPoint;
-    rect.size.width = (int)(conRect.size.width);
-    rect.size.height = (int)(conRect.size.height);
-
-#ifdef __APPLE__    // Apple
-    [NSGraphicsContext saveGraphicsState];
-    bitmapImage = [[NSBitmapImageRep alloc] initWithBitmapDataPlanes:NULL
-                                                          pixelsWide:rect.size.width
-                                                          pixelsHigh:rect.size.height
-                                                       bitsPerSample:8
-                                                     samplesPerPixel:4
-                                                            hasAlpha:YES isPlanar:NO // YES - geht nicht
-                                                      colorSpaceName:NSCalibratedRGBColorSpace
-                                                        bitmapFormat:0
-                                                         bytesPerRow:rect.size.width*4
-                                                        bitsPerPixel:32];
-
-    /* this is the important code for the correct Color Values - need kCGColorSpaceGenericRGB since 10.4 */
-    {   CGColorSpaceRef colorSpace = CGColorSpaceCreateWithName(kCGColorSpaceGenericRGB);
-
-        cgContext = CGBitmapContextCreate([bitmapImage bitmapData], rect.size.width, rect.size.height, 8, rect.size.width*4,
-                                          colorSpace, kCGImageAlphaPremultipliedLast);
-        gContext = [NSGraphicsContext graphicsContextWithGraphicsPort:cgContext
-                                                              flipped:[[NSGraphicsContext currentContext] isFlipped]];
-        CGColorSpaceRelease(colorSpace);
-    }
-    [NSGraphicsContext setCurrentContext:gContext];
-#else               // OpenStep and GNUstep
-    /* build an offscreen window
-     * in which we draw the scaled black copy of original path on white background NSBackingStoreBuffered NSBackingStoreRetained
-     */
-    win = [[NSWindow alloc] initWithContentRect:conRect styleMask:NSBorderlessWindowMask backing:NSBackingStoreRetained defer:NO];
-    [win setDepthLimit:NSBestDepth(NSCalibratedWhiteColorSpace, 8, 8, YES, NULL)];
-
-    [win setBackgroundColor:[NSColor whiteColor]];
-#if DEBUG_TIFFEXPORT
-    [win makeKeyAndOrderFront:self]; /* weglassen wenn nicht gesehen werden soll */
-#endif
-    conView = [win contentView];
-    [conView display];
-
-    /* now draw our black scaled path in view
-     */
-    [conView lockFocus];
-#endif
-
-#ifdef __APPLE__
-    /* draw color shading without antialiasing */
-    [[NSGraphicsContext currentContext] setShouldAntialias:Prefs_Antialias];
-
-    /* first draw white rectangle in full size */
-    {   VRectangle  *r = [VRectangle rectangle];
-
-        [r setFilled: YES];
-        [r setFillColor:[NSColor whiteColor]];
-        [r setVertices:rect.origin :NSMakePoint(rect.size.width, rect.size.height)];
-        [r drawWithPrincipal:nil];
-    }
-#endif
-
-    /* draw all visible Layers */
-    {   int     l, cnt = [layerList count];
-        NSPoint movePt = NSMakePoint(-bbox.origin.x, -bbox.origin.y);
-        NSPoint moveBackPt = bbox.origin; // NSMakePoint(-bbox.origin.x, -bbox.origin.y);
-
-        for (l=0; l<cnt; l++)
-        {	LayerObject	*layerObject = [layerList objectAtIndex:l];
-
-            if ( [layerObject state] ) // visible                
-            {   NSMutableArray	*llist = [layerObject list];
-                int i, lcnt = [llist count];
-
-                for (i=0; i<lcnt; i++)
-                {   VGraphic    *gr = [llist objectAtIndex:i];
-
-                    [gr moveBy:movePt];
-                    [gr drawWithPrincipal:nil];
-                    [gr moveBy:moveBackPt];
-                }
-            }
-        }
-    }
-
-    /* get pixel information into data (char string) */
-
-#if !defined(__APPLE__)    // OpenStep 4.2 and GNUstep
-    bitmapImage = [[NSBitmapImageRep allocWithZone:[self zone]] initWithFocusedViewRect:rect];
-#endif
-
-    /* generate Image from bitmapRep */
-    img = [[NSImage alloc] initWithSize:rect.size];
-    [img addRepresentation:bitmapImage];
-
-    /* save image */
-    if ( (tdata = [img TIFFRepresentation]) )
-    {   [tdata writeToFile:filename atomically:YES];
-        return YES;
-    }
-
-#ifdef __APPLE__
-    [NSGraphicsContext restoreGraphicsState];
-    CGContextRelease(cgContext);
-#else
-    [conView unlockFocus];
-    [win close];
-#endif
-
-    [img release];
-    [bitmapImage release];
-    return NO;
-}
-#if 0
-/*{   NSPasteboard	*pb = [NSPasteboard pasteboardWithName:@"pasteboard"];
-    NSImage         *img;
-    NSData          *tdata = nil;
-    NSRect          bbox;
-
-    bbox = [[self documentView] boundsOfArray:[[self documentView] layerList]];
-
-    [[self documentView] writeEPSInsideRect:bbox toPasteboard:pb]; // did not work (antialiased and no white)
-    img = [[NSImage alloc] initWithPasteboard:pb];
-    if ( (tdata = [img TIFFRepresentation]) )
-    {   [tdata writeToFile:filename atomically:YES];
-        return YES;
-    }
-    [img release];
-    [pb releaseGlobally];
-    return NO;
-}*/
-#endif
-
 - (void)printSeparation:(NSPrintOperation*)op
-{   NSColor             *sepColor;
-    NSPrintOperation    *sop=nil;
-    NSPrintInfo         *pi = [op printInfo], *spi;
-    NSMutableDictionary *piDict = [pi dictionary];
-    NSAutoreleasePool   *pool0 = [NSAutoreleasePool new], *pool;
-    NSString            *cropPath;
-    NSString            *pStr=nil, *npStr=nil, *pExt=nil, *mStr, *paperName = [pi paperName];
-    NSMutableArray      *ml, *mlist=[NSMutableArray array], *layerList;
-    NSRect              mBounds, pageRect = NSZeroRect, newPageRect = NSZeroRect, oldFrame, visibleRect;
-    NSPoint             mPosition = NSZeroPoint, mOffset, lr, ll, ur, ul, center, dm, pOffset = {55.0, 55.0};
-    int                 i, orientation = [pi orientation];
-    DocView             *docView = [self documentView];
-    float               width, height, scale = [docView scaleFactor];
-
-    cropPath = vhfPathWithPathComponents([[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER, nil);
+{   NSColor		*sepColor;
+    NSPrintOperation	*sop=nil;
+    NSPrintInfo		*pi = [op printInfo], *spi;
+    NSMutableDictionary	*piDict = [pi dictionary];
+    NSAutoreleasePool	*pool0 = [NSAutoreleasePool new], *pool;
+    NSString		*pStr=nil, *npStr=nil, *pExt=nil, *mStr, *paperName = [pi paperName];
+    NSMutableArray	*ml, *mlist=[NSMutableArray array], *layerList;
+    NSRect		mBounds, pageRect = NSZeroRect, newPageRect = NSZeroRect, oldFrame, visibleRect;
+    NSPoint		mPosition, mOffset, lr, ll, ur, ul, center, dm, pOffset = {55.0, 55.0};
+    int			i, orientation = [pi orientation];
+    DocView		*docView = [self documentView];
+    float		width, height, scale = [docView scaleFactor];
 
     if ([piDict objectForKey:NSPrintSavePath])
     {
@@ -1518,7 +1189,7 @@ static NSMutableArray *zoneList = nil;
     [docView setFrameSize:NSMakeSize(width, height)];
 
     /* up left - get separation mark */
-    mStr = vhfPathWithPathComponents(cropPath, @"leftup.cenon", nil);
+    mStr = [NSString stringWithFormat:@"%@/%@/leftup.cenon", [[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER];
     ml = [Document listFromFile:mStr];
     /* get mark position */
     for (i=[ml count]-1; i>=0; i--)
@@ -1540,9 +1211,9 @@ static NSMutableArray *zoneList = nil;
         [mlist addObject:[ml objectAtIndex:i]];
 
     /* down right - (upleft 180 rotatet) get separation mark */
-    mStr = vhfPathWithPathComponents(cropPath, @"leftup.cenon", nil);
+    mStr = [NSString stringWithFormat:@"%@/%@/leftup.cenon", [[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER];
     ml = [Document listFromFile:mStr];
-    mBounds = [docView boundsOfArray:ml withKnobs:NO];
+    mBounds = [docView boundsOfArray:ml];
     center.x = mBounds.origin.x + mBounds.size.width/2.0;
     center.y = mBounds.origin.y + mBounds.size.height/2.0;
     /* rotate around 180 */
@@ -1568,7 +1239,7 @@ static NSMutableArray *zoneList = nil;
         [mlist addObject:[ml objectAtIndex:i]];
 
     /* right up - get separation mark */
-    mStr = vhfPathWithPathComponents(cropPath, @"rightup.cenon", nil);
+    mStr = [NSString stringWithFormat:@"%@/%@/rightup.cenon", [[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER];
     ml = [Document listFromFile:mStr];
     /* get mark position */
     for (i=[ml count]-1; i>=0; i--)
@@ -1590,9 +1261,9 @@ static NSMutableArray *zoneList = nil;
         [mlist addObject:[ml objectAtIndex:i]];
 
     /* down left - (right up rotate with 180) get separation mark */
-    mStr = vhfPathWithPathComponents(cropPath, @"rightup.cenon", nil);
+    mStr = [NSString stringWithFormat:@"%@/%@/rightup.cenon", [[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER];
     ml = [Document listFromFile:mStr];
-    mBounds = [docView boundsOfArray:ml withKnobs:NO];
+    mBounds = [docView boundsOfArray:ml];
     center.x = mBounds.origin.x + mBounds.size.width/2.0;
     center.y = mBounds.origin.y + mBounds.size.height/2.0;
     /* rotate around 180 */
@@ -1618,7 +1289,7 @@ static NSMutableArray *zoneList = nil;
         [mlist addObject:[ml objectAtIndex:i]];
 
     /* down middle */
-    mStr = vhfPathWithPathComponents(cropPath, @"middledown.cenon", nil);
+    mStr = [NSString stringWithFormat:@"%@/%@/middledown.cenon", [[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER];
     ml = [Document listFromFile:mStr];
     /* get mark position */
     for (i=[ml count]-1; i>=0; i--)
@@ -1642,9 +1313,9 @@ static NSMutableArray *zoneList = nil;
         [mlist addObject:[ml objectAtIndex:i]];
 
     /* right middle */
-    mStr = vhfPathWithPathComponents(cropPath, @"middledown.cenon", nil);
+    mStr = [NSString stringWithFormat:@"%@/%@/middledown.cenon", [[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER];
     ml = [Document listFromFile:mStr];
-    mBounds = [docView boundsOfArray:ml withKnobs:NO];
+    mBounds = [docView boundsOfArray:ml];
     center.x = mBounds.origin.x + mBounds.size.width/2.0;
     center.y = mBounds.origin.y + mBounds.size.height/2.0;
     /* rotate around 180 */
@@ -1672,9 +1343,9 @@ static NSMutableArray *zoneList = nil;
         [mlist addObject:[ml objectAtIndex:i]];
 
     /* left middle */
-    mStr = vhfPathWithPathComponents(cropPath, @"middledown.cenon", nil);
+    mStr = [NSString stringWithFormat:@"%@/%@/middledown.cenon", [[NSBundle mainBundle] resourcePath], CROPMARK_FOLDER];
     ml = [Document listFromFile:mStr];
-    mBounds = [docView boundsOfArray:ml withKnobs:NO];
+    mBounds = [docView boundsOfArray:ml];
     center.x = mBounds.origin.x + mBounds.size.width/2.0;
     center.y = mBounds.origin.y + mBounds.size.height/2.0;
     /* rotate around 180 */
@@ -1879,12 +1550,12 @@ static NSMutableArray *zoneList = nil;
  * modified: 2005-09-01
  */
 - (void)printDocument:sender
-{   NSPrintOperation    *op;
-    NSPrintPanel        *pp;
-    NSPrintInfo         *pi;
-    DocView             *docView = [self documentView];
-    NSRect              visibleRect, oldFrame;
-    float               width, height, scale = [docView scaleFactor];
+{   NSPrintOperation	*op;
+    NSPrintPanel	*pp;
+    NSPrintInfo		*pi;
+    DocView		*docView = [self documentView];
+    NSRect		visibleRect, oldFrame;
+    float		width, height, scale = [docView scaleFactor];
 
     /* set scale to 1.0 */
     scale = [docView scaleFactor];
@@ -1908,7 +1579,7 @@ static NSMutableArray *zoneList = nil;
     /* single page document */
     else
     {
-        /* FIXME: GNUstep printing needs to be fixed to work with the code below */
+        /* FIXME: GNUstep printing needs to be fixed for the code below */
 #ifdef GNUSTEP_BASE_VERSION
         op = [NSPrintOperation printOperationWithView:[self documentView] printInfo:printInfo];
         [op setShowPanels:YES];
@@ -2019,18 +1690,18 @@ static NSMutableArray *zoneList = nil;
     if ( dirty )
         switch (NSRunAlertPanel(CLOSEWINDOW_STRING, SAVECHANGES_STRING, SAVE_STRING, DONTSAVE_STRING, CANCEL_STRING, [sender title]))
         {
-            case NSAlertDefaultReturn:      // save
+            case NSAlertDefaultReturn:		// save
                 [self save];
                 break;
-            case NSAlertAlternateReturn:    // dont save
+            case NSAlertAlternateReturn:	// dont save
                 break;
-            default:                        // cancel
+            default:				// cancel
                 return NO;
         }
 
     for (l=[[[self documentView] layerList] count]-1; l>=0; l--)
         [[[[self documentView] layerList] objectAtIndex:l] setDirty:NO];
-    [window endEditingFor:nil]; // end editing of text
+
     [window setDocument:nil];
     [self autorelease];
 
@@ -2038,13 +1709,10 @@ static NSMutableArray *zoneList = nil;
 }
 - (void)windowDidResignKey:(NSNotification *)notification
 {   [window windowDidResignKey:notification]; }
-- (void)windowDidBecomeKey:(NSNotification *)notification
-{   [window windowDidBecomeKey:notification]; }
 - (void)windowDidBecomeMain:(NSNotification *)notification
 {   [window windowDidBecomeMain:notification]; }
 - (void)windowDidResignMain:(NSNotification *)notification
 {
-    [window endEditingFor:nil]; // end editing of text
     [[NSNotificationCenter defaultCenter] postNotificationName:DocWindowDidChange
                                                         object:nil];
 }
@@ -2056,7 +1724,6 @@ static NSMutableArray *zoneList = nil;
         [self save];*/
     [printInfo release];
     [fontObject release];
-    [docSettingsDict release];
     [super dealloc];
 }
 
