@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-29
- * modified: 2005-01-07
+ * modified: 2005-09-03 (punch stuff)
  *
  * the group is implemented as follows:
  * - all objects are stored in a list with absolute coordinates
@@ -136,15 +136,82 @@
     for (i=[list count]-1; i>=0; i--)
     {	id	g = [list objectAtIndex:i];
 
-        if ( [g isKindOfClass:[VGroup class]] || [g isKindOfClass:[VPath class]] )
+        if ( [g isKindOfClass:[VGroup class]] ) // || [g isKindOfClass:[VPath class]] 
             cnt += [g countRecursive];
     }
     return cnt;
 }
+/* created 2005-08-19
+ */
+- (id)recursiveObjectAtIndex:(int)ix
+{   int	i, cnt = [list count], cCnt = 0;
 
-/* created:  24.09.95
- * modified:
- * purpose:
+    for (i=0; i < cnt; i++)
+    {	id	g = [list objectAtIndex:i];
+
+        if ([g isKindOfClass:[VGroup class]])
+        { int	gCnt = [g countRecursive];
+
+            if (ix >= cCnt && ix < cCnt+gCnt) // obj is inside g
+                return [g recursiveObjectAtIndex:(ix-cCnt)];
+            cCnt += [g countRecursive];
+        }
+        else if (cCnt == ix)
+            return g;
+        else
+            cCnt++;
+    }
+    return nil;
+}
+- (void)recursiveRemoveObjectAtIndex:(int)ix
+{   int	i, cnt = [list count], cCnt = 0;
+
+    for (i=0; i < cnt; i++)
+    {	id	g = [list objectAtIndex:i];
+
+        if ([g isKindOfClass:[VGroup class]])
+        {   int	gCnt = [g countRecursive];
+
+            if (ix >= cCnt && ix < cCnt+gCnt) // obj is inside g
+                return [g recursiveRemoveObjectAtIndex:(ix-cCnt)];
+            cCnt += [g countRecursive];
+        }
+        else if (cCnt == ix)
+            return [list removeObjectAtIndex:i];
+        else
+            cCnt++;
+    }
+}
+- (void)recursiveInsertObject:(id)obj atIndex:(int)ix
+{   int	i, cnt = [list count], cCnt = 0;
+
+    if (ix >= [self countRecursive])
+    {
+        if ([[list objectAtIndex:cnt-1] isKindOfClass:[VGroup class]]) // last obj is a group
+            [[[list objectAtIndex:cnt-1] list] addObject:obj];
+        else
+            [list addObject:obj];
+    }
+
+    for (i=0; i < cnt; i++)
+    {	id	g = [list objectAtIndex:i];
+
+        if ([g isKindOfClass:[VGroup class]])
+        {   int	gCnt = [g countRecursive];
+
+            if (ix >= cCnt && ix < cCnt+gCnt) // obj is inside g
+                return [g recursiveInsertObject:obj atIndex:(ix-cCnt)];
+            cCnt += [g countRecursive];
+        }
+        else if (cCnt == ix)
+            return [list insertObject:obj atIndex:i];
+        else
+            cCnt++;
+    }
+}
+
+/* created:  1995-09-24
+ * modified: 
  */
 - (void)deselectAll
 {   int	i;
@@ -165,6 +232,8 @@
     NSPoint	rc0={0.5,0.5}, rc1={0.5,0.5};
 
     uniColoring = NO;
+    if (![list count])
+        return;
     gr0 = [list objectAtIndex:0];
     if ( [gr0 isKindOfClass:[VGroup class]] && [(VGroup*)gr0 uniColored] == NO )
         return;
@@ -208,7 +277,7 @@
 }
 
 - (void)setColorNew
-{   int		i, cnt, fild0=0, fild1=0;
+{   int		i, cnt, fild0 = 0, fild1 = 0;
     VGraphic	*gr0, *gr1;
     NSColor	*col0, *fcol0 = nil, *ecol0 = nil, *col1, *fcol1 = nil, *ecol1 = nil;
     float	w0 = 0, ga0 = 0, w1 = 0, ga1 = 0;
@@ -220,11 +289,13 @@
     width = 0.0;
     filled = NO;
     fillColor = [[NSColor blackColor] retain];
-    endColor = [[NSColor blackColor] retain];
+    endColor  = [[NSColor blackColor] retain];
     graduateAngle = 0.0;
     stepWidth = 7.0;
     radialCenter = NSMakePoint(0.5, 0.5);
 
+    if (![list count])	// empty group
+        return;
     gr0 = [list objectAtIndex:0];
     if ( [gr0 isKindOfClass:[VGroup class]] && [(VGroup*)gr0 uniColored] == NO )
         return;
@@ -421,11 +492,12 @@
 - (void)setSelected:(BOOL)flag
 {
     if (!flag)
-    {	if (selectedObject >= 0)
+    {
+        if (selectedObject >= 0)
             [[list objectAtIndex:selectedObject] setSelected:NO];
         selectedObject = -1;
     }
-    return [super setSelected:flag];
+    [super setSelected:flag];
 }
 
 /* returns the old list
@@ -1119,6 +1191,7 @@
     return group;
 }
 
+#if 0
 - getListOfObjectsSplittedFrom:(NSPoint*)pArray :(int)iCnt
 {   NSMutableArray	*splitList = [NSMutableArray array], *spList = nil;
     int			i, j, cnt = [list count];
@@ -1143,10 +1216,10 @@
 }
 
 - (int)getIntersections:(NSPoint**)ppArray with:g
-{   int		i, j, iCnt = 0;
+{   int		i, j, iCnt = 0, ptsCnt = Min(100, [self numPoints]);
     NSPoint	*pts;
 
-    *ppArray = malloc(([list count]*9) * sizeof(NSPoint));
+    *ppArray = malloc(ptsCnt * sizeof(NSPoint));
     for (i=[list count]-1; i>=0; i--)
     {	id	gp = [list objectAtIndex:i];
         int	cnt, oldCnt = iCnt;
@@ -1155,6 +1228,9 @@
             continue;
 
         cnt = [gp getIntersections:&pts with:g];	/* line, arc, curve */
+        if (iCnt+cnt >= ptsCnt)
+            *ppArray = realloc(*ppArray, (ptsCnt+=cnt*2) * sizeof(NSPoint));
+
         for (j=0; j<cnt; j++)
         {
             if ( !pointInArray(pts[j], *ppArray, oldCnt) )
@@ -1213,6 +1289,7 @@
 
     return iCnt;
 }
+#endif
 
 - (float)sqrDistanceGraphic:g
 {   int		i;
@@ -1295,15 +1372,15 @@
 
     return newGroup;
 }*/
-
+#if 0
 - getIntersectionsAndSplittedObjects:(NSPoint**)ppArray :(int*)iCnt with:g
-{   int			i, j, lCnt = [list count];
+{   int			i, j, lCnt = [list count], ptsCnt = Min(100, [self numPoints]);
     NSPoint		*pts;
     NSRect		gBounds = [g bounds];
     NSMutableArray	*splitList = [NSMutableArray array], *spList = nil;
 
     *iCnt = 0;
-    *ppArray = malloc(([list count]*9) * sizeof(NSPoint));
+    *ppArray = malloc(ptsCnt * sizeof(NSPoint));
 //    for (i=[list count]-1; i>=0; i--)
     for (i=0; i<lCnt; i++)
     {	id	gp = [list objectAtIndex:i];
@@ -1331,6 +1408,10 @@
             else
                 [splitList addObject:[[gp copy] autorelease]];
         }
+
+        if ((*iCnt)+cnt >= ptsCnt)
+            *ppArray = realloc(*ppArray, (ptsCnt+=cnt*2) * sizeof(NSPoint));
+
         for (j=0; j<cnt; j++)
         {
             if ( !pointInArray(pts[j], *ppArray, oldCnt) )
@@ -1478,6 +1559,7 @@
     [pool release];
     return ng;
 }
+#endif
 
 - (void)writeFilesToDirectory:(NSString*)directory
 {   int	i;
