@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-25
- * modified: 2005-01-06
+ * modified: 2005-03-31
  *
  * This file is part of the vhf Import Library.
  *
@@ -209,7 +209,7 @@
 static NSString	*prolog = nil;
 - importPS:(NSData*)psData
 {   NSString		*app = [[NSProcessInfo processInfo] processName], *commandLine, *path;
-    NSString		*inFile = [NSString stringWithFormat:@"/tmp/%@_psImport.in", app];
+    NSString		*inFile  = [NSString stringWithFormat:@"/tmp/%@_psImport.in", app];
     NSString		*outFile = [NSString stringWithFormat:@"/tmp/psImport.out"]; // see psImport.prolog
     NSMutableString	*data = [NSMutableString string];
 
@@ -251,10 +251,10 @@ static NSString	*prolog = nil;
     data = [[[NSString alloc] initWithContentsOfFile:outFile] autorelease];
 
     /* interpret data and send to receiving object */
-    if ( ![self interpret:data] )
+    if ( !data || ![self interpret:data] )
         return nil;
 
-    [[NSFileManager defaultManager] removeFileAtPath:inFile handler:nil];
+    [[NSFileManager defaultManager] removeFileAtPath:inFile  handler:nil];
     [[NSFileManager defaultManager] removeFileAtPath:outFile handler:nil];
 
     return [list autorelease];
@@ -371,8 +371,11 @@ static NSString	*prolog = nil;
                 ok = NO; break;
             }
             //[state.color release];	// FIXME: this should be active but creates a crash ???
-            state.color = [[NSColor colorWithCalibratedRed:(1.0-c[cCnt-5])*k green:(1.0-c[cCnt-4])*k blue:(1.0-c[cCnt-3])*k alpha:c[cCnt-1]] retain];
-            //state.color = [NSColor colorWithDeviceCyan:c[cCnt-5] magenta:c[cCnt-4] yellow:c[cCnt-3] black:c[cCnt-2] alpha:c[cCnt-1]];
+            /*
+             * (k-c[cCnt-5]) instead (1.0-c[cCnt-5])*k
+             */
+            state.color = [[NSColor colorWithCalibratedRed:(k-c[cCnt-5]) green:(k-c[cCnt-4]) blue:(k-c[cCnt-3]) alpha:c[cCnt-1]] retain];
+            //state.color = [[NSColor colorWithCalibratedRed:(1.0-c[cCnt-5])*k green:(1.0-c[cCnt-4])*k blue:(1.0-c[cCnt-3])*k alpha:c[cCnt-1]] retain];
             cCnt = 0;
         }
         else if ( [scanner scanString:CURVE intoString:NULL] )		// curve
